..
    Copyright (C) 2020-2024 CERN.
    Copyright (C) 2024 Graz University of Technology.

    Invenio-Banners is free software; you can redistribute it and/or modify
    it under the terms of the MIT License; see LICENSE file for more details.

Changes
=======

Version v4.1.0 (released 2025-01-22)

- templates: pass ui classes through macro parameters

Version v4.0.0 (released 2024-12-10)

- setup: change to reusable workflows
- setup: bump major dependencies

Version v3.2.0 (released 2024-11-05)

- feat(administration): use html editor for message
- global: change the code to be compatible with sqlalchemy >= 2.0
- global: add compatibility layer to move to flask >= 3.0

Version v3.1.0 (released 2024-08-07)

- http headers: use and adjust vnd.inveniordm.v1+json http accept header

Version 3.0.2 (released 2024-07-17)

- errors: implement REST validation error for banner loader

Version 3.0.1 (released 2024-02-21)

- Moved admin menu item for banners to site administration category

Version 3.0.0 (released 2024-01-31)

- installation: bump invenio-administration

Version 2.1.1 (released 2023-07-24)

- ui: remove bottom margin

Version 2.1.0 (released 2023-03-02)

- remove deprecated flask-babelex imports
- install invenio-i18n explicitly

Version 2.0.0 (released 2023-02-15)

- global: refactor into resource/service pattern
- global: implement CRUD operations
- global: implement best practices for packaging (declarative cfg), code
  linting (black) and testing
- search: improve banners search by query params
- administration: integrate banners view module


Version 1.0.0a1 (release 2020-10-25)
------------------------------------

- Initial public release.
